@@ -216,7 +216,7 @@ class Sector:
         self,
         text: str,
         x: float | None = None,
-        r: float = 110,
+        r: float = 105,
         *,
         orientation: str = "horizontal",
         **kwargs,
@@ -230,7 +230,7 @@ class Sector:
         x: float, optional
             X position. If None, sector center x is set.
         r : float, optional
-            Radius position. By default, outside position r=110 is set.
+            Radius position. By default, outer position `r=105` is set.
         orientation : str, optional
             Text orientation (`horizontal` or `vertical`)
         **kwargs : dict, optional
