@@ -628,89 +628,62 @@ class Track:
         x: list[float] | np.ndarray,
         height: list[float] | np.ndarray,
         width: float = 0.8,
-        bottom: float = 0,
-        top: float | None = None,
-        *,
+        bottom: float | list[float] | np.ndarray = 0,
         align: str = "center",
-        facecolor: str | list[str] = "tab:blue",
+        *,
+        vmin: float = 0,
+        vmax: float | None = None,
         **kwargs,
     ) -> None:
         """Plot bar
 
-        For plot speed reasons, don't use matplotlib's `Axes.bar` method internally.
-        Self-implemented bar method with equivalent functionality of `Axes.bar` is used.
-
         Parameters
         ----------
         x : list[float] | np.ndarray
-            Bar X coordinates
+            Bar x coordinates
         height : list[float] | np.ndarray
             Bar heights
         width : float, optional
             Bar width
-        bottom : float, optional
-            Bar bottom limit value
-        top : float | None, optional
-            Bar top limit value. If None, `max(height)` is set.
+        bottom : float | np.ndarray, optional
+            Bar bottom(s)
         align : str, optional
             Bar alignment type (`center` or `edge`)
-        facecolor : str | list[str], optional
-            Bar facecolor(s)
+        vmin : float, optional
+            Y min value
+        vmax : float | None, optional
+            Y max value. If None, `np.max(height + bottom)` is set.
         **kwargs : dict, optional
-            Patch properties (e.g. `fc="tomato", ec="black", lw=0.5, hatch="//"`)
-            <https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html>
+            Axes.bar properties (e.g. `color="tomato", ec="black", lw=0.5, hatch="//"`)
+            <https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.bar.html>
         """
         # Check x, height list length
         if len(x) != len(height):
             err_msg = f"List length is not match ({len(x)=}, {len(height)=})"
             raise ValueError(err_msg)
 
-        # Convert (x, y) to (rad, r)
-        x = list(map(self.x_to_rad, x))
-        top = max(height) if top is None else top
-        self._check_value_min_max(height, bottom, top)
-        height = [self._y_to_r(v, bottom, top) for v in height]
-        height = np.array(height) - min(self.r_plot_lim)
-        width = self.rad_size * (width / self.size)
+        # Calculate top & vmax
+        if isinstance(bottom, (list, tuple, np.ndarray)):
+            bottom = np.array(bottom)
+        else:
+            bottom = np.array([bottom])
+        top = np.array(height) + bottom
+        vmax = max(top) if vmax is None else vmax
 
-        # Don't use matplotlib's `Axes.bar` method
-        #
-        # def plot_bar(ax: PolarAxes) -> None:
-        #     ax.bar(x, height, width, self.r_plot_lim[0], **kwargs)
-        # self._plot_funcs.append(plot_bar)
+        # Check if bottom & top(height + bottom) is in valid min-max range
+        self._check_value_min_max(bottom, vmin, vmax)
+        self._check_value_min_max(top, vmin, vmax)
 
-        for idx, (rad, h) in enumerate(zip(x, height)):
-            # Set radian & r position
-            if align == "center":
-                radr = (rad - (width / 2), min(self.r_plot_lim))
-            elif align == "edge":
-                radr = (rad, min(self.r_plot_lim))
-            else:
-                raise ValueError(f"{align=} is invalid ('center' or 'edge').")
-            # Set facecolor(s)
-            if isinstance(facecolor, (list, tuple)):
-                kwargs.update(dict(facecolor=facecolor[idx]))
-            else:
-                kwargs.update(dict(facecolor=facecolor))
-            # Add bar rectangle patch
-            bar_arc_rect = ArcRectangle(radr, width, h, **kwargs)
-            self._patches.append(bar_arc_rect)
-
-    def hist(
-        self,
-        x: list[float] | np.ndarray,
-        bins: int,
-    ) -> None:
-        """Plot histogram"""
-        # TODO: Implement histogram method
-        raise NotImplementedError
+        # Calculate bar params
         rad = list(map(self.x_to_rad, x))
-        bins_rad = self.x_to_rad(bins)
+        r_bottom = np.array([self._y_to_r(v, vmin, vmax) for v in bottom])
+        r_height = [self._y_to_r(v, vmin, vmax) for v in top] - r_bottom
+        rad_width = self.rad_size * (width / self.size)
 
-        def plot_hist(ax: PolarAxes) -> None:
-            ax.hist(rad, bins_rad)
+        def plot_bar(ax: PolarAxes) -> None:
+            ax.bar(rad, r_height, rad_width, r_bottom, align=align, **kwargs)
 
-        self._plot_funcs.append(plot_hist)
+        self._plot_funcs.append(plot_bar)
 
     def fill_between(
         self,
@@ -735,7 +708,7 @@ class Track:
         vmin : float | None, optional
             Y min value
         vmax : float | None, optional
-            Y max value.
+            Y max value. If None, `max(y1 + y2)` is set.
         **kwargs : dict, optional
             Axes.fill_between properties (e.g. `fc="red", ec="black", lw=0.1, ...`)
             <https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.fill_between.html>
@@ -942,7 +915,8 @@ class Track:
             else:
                 continue
             label = str(node.name) if label_formatter is None else label_formatter(node)
-
+            if label == "":
+                continue
             x, r = name2xr[node.name]
             r = r + label_margin if outer else r - label_margin
             rad = self.x_to_rad(x)
@@ -956,7 +930,7 @@ class Track:
         *,
         plotstyle: str = "box",
         r_lim: tuple[float, float] | None = None,
-        facecolor_handle_func: Callable[[SeqFeature], str] | None = None,
+        facecolor_handler: Callable[[SeqFeature], str] | None = None,
         **kwargs,
     ) -> None:
         """Plot genomic features
@@ -968,8 +942,8 @@ class Track:
         plotstyle : str, optional
             Plot style (`box` or `arrow`)
         r_lim : tuple[float, float] | None, optional
-            Radius limit range. If None, track's r_lim is set.
-        facecolor_handle_func : Callable[[SeqFeature], str] | None, optional
+            Radius limit range. If None, `track.r_plot_lim` is set.
+        facecolor_handler : Callable[[SeqFeature], str] | None, optional
             User-defined function to handle facecolor
         **kwargs : dict, optional
             Patch properties (e.g. `fc="red", ec="blue", lw=1.0, ...`)
@@ -987,8 +961,8 @@ class Track:
             if tag_color is not None:
                 kwargs.update(dict(fc=tag_color, facecolor=tag_color))
             # Set facecolor by user-defined function
-            if facecolor_handle_func is not None:
-                color = facecolor_handle_func(feature)
+            if facecolor_handler is not None:
+                color = facecolor_handler(feature)
                 kwargs.update(dict(fc=color, facecolor=color))
             # Plot feature
             try:
